@@ -6,7 +6,7 @@
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at
 
-      http://www.apache.org/licenses/LICENSE-2.0
+      https://www.apache.org/licenses/LICENSE-2.0
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,6 +23,7 @@ import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Objects;
+import java.util.function.Supplier;
 
 /**
  * Describes a single command-line option. It maintains information regarding the short-name of the option, the long-name, if any exists, a flag indicating if
@@ -31,7 +32,7 @@ import java.util.Objects;
  * An Option is not created independently, but is created through an instance of {@link Options}. An Option is required to have at least a short or a long-name.
  * </p>
  * <p>
- * <b>Note:</b> once an {@link Option} has been added to an instance of {@link Options}, its required flag cannot be changed.
+ * <strong>Note:</strong> once an {@link Option} has been added to an instance of {@link Options}, its required flag cannot be changed.
  * </p>
  *
  * @see org.apache.commons.cli.Options
@@ -51,7 +52,7 @@ public class Option implements Cloneable, Serializable {
      *
      * @since 1.3
      */
-    public static final class Builder {
+    public static final class Builder implements Supplier<Option> {
 
         /** The default type. */
         private static final Class<String> DEFAULT_TYPE = String.class;
@@ -116,7 +117,7 @@ public class Option implements Cloneable, Serializable {
          * Sets the display name for the argument value.
          *
          * @param argName the display name for the argument value.
-         * @return this builder, to allow method chaining.
+         * @return {@code this} instance..
          */
         public Builder argName(final String argName) {
             this.argName = argName;
@@ -128,12 +129,11 @@ public class Option implements Cloneable, Serializable {
          *
          * @return the new {@link Option}.
          * @throws IllegalArgumentException if neither {@code opt} or {@code longOpt} has been set.
+         * @deprecated Use {@link #get()}.
          */
+        @Deprecated
         public Option build() {
-            if (option == null && longOption == null) {
-                throw new IllegalArgumentException("Either opt or longOpt must be specified");
-            }
-            return new Option(this);
+            return get();
         }
 
         /**
@@ -143,7 +143,7 @@ public class Option implements Cloneable, Serializable {
          * </p>
          *
          * @param converter the Converter to use.
-         * @return this builder, to allow method chaining.
+         * @return {@code this} instance..
          * @since 1.7.0
          */
         public Builder converter(final Converter<?, ?> converter) {
@@ -177,17 +177,28 @@ public class Option implements Cloneable, Serializable {
          * Sets the description for this option.
          *
          * @param description the description of the option.
-         * @return this builder, to allow method chaining.
+         * @return {@code this} instance..
          */
         public Builder desc(final String description) {
             this.description = description;
             return this;
         }
 
+        /**
+         * Constructs an Option with the values declared by this {@link Builder}.
+         *
+         * @return the new {@link Option}.
+         * @throws IllegalStateException if neither {@code opt} or {@code longOpt} has been set.
+         */
+        @Override
+        public Option get() {
+            return new Option(this);
+        }
+
         /**
          * Tests whether the Option will require an argument.
          *
-         * @return this builder, to allow method chaining.
+         * @return {@code this} instance..
          */
         public Builder hasArg() {
             return hasArg(true);
@@ -197,7 +208,7 @@ public class Option implements Cloneable, Serializable {
          * Tests whether the Option has an argument or not.
          *
          * @param hasArg specifies whether the Option takes an argument or not.
-         * @return this builder, to allow method chaining.
+         * @return {@code this} instance..
          */
         public Builder hasArg(final boolean hasArg) {
             // set to UNINITIALIZED when no arg is specified to be compatible with OptionBuilder
@@ -317,7 +328,7 @@ public class Option implements Cloneable, Serializable {
         /**
          * The Option will use {@code sep} as a means to separate argument values.
          * <p>
-         * <b>Example:</b>
+         * <strong>Example:</strong>
          * </p>
          *
          * <pre>
@@ -423,8 +434,12 @@ public class Option implements Cloneable, Serializable {
      * Private constructor used by the nested Builder class.
      *
      * @param builder builder used to create this option.
+     * @throws IllegalStateException if neither {@code opt} or {@code longOpt} has been set.
      */
     private Option(final Builder builder) {
+        if (builder.option == null && builder.longOption == null) {
+            throw new IllegalStateException("Either opt or longOpt must be specified");
+        }
         this.argName = builder.argName;
         this.description = builder.description;
         this.longOption = builder.longOption;
@@ -445,7 +460,6 @@ public class Option implements Cloneable, Serializable {
      * @param option      short representation of the option.
      * @param hasArg      specifies whether the Option takes an argument or not.
      * @param description describes the function of the option.
-     *
      * @throws IllegalArgumentException if there are any non valid Option characters in {@code opt}.
      */
     public Option(final String option, final boolean hasArg, final String description) throws IllegalArgumentException {
@@ -457,7 +471,6 @@ public class Option implements Cloneable, Serializable {
      *
      * @param option      short representation of the option.
      * @param description describes the function of the option.
-     *
      * @throws IllegalArgumentException if there are any non valid Option characters in {@code opt}.
      */
     public Option(final String option, final String description) throws IllegalArgumentException {
@@ -471,7 +484,6 @@ public class Option implements Cloneable, Serializable {
      * @param longOption  the long representation of the option.
      * @param hasArg      specifies whether the Option takes an argument or not.
      * @param description describes the function of the option.
-     *
      * @throws IllegalArgumentException if there are any non valid Option characters in {@code opt}.
      */
     public Option(final String option, final String longOption, final boolean hasArg, final String description) throws IllegalArgumentException {
@@ -520,8 +532,7 @@ public class Option implements Cloneable, Serializable {
      */
     @Deprecated
     public boolean addValue(final String value) {
-        throw new UnsupportedOperationException(
-                "The addValue method is not intended for client use. Subclasses should use the processValue method instead.");
+        throw new UnsupportedOperationException("The addValue method is not intended for client use. Subclasses should use the processValue method instead.");
     }
 
     /**
@@ -668,7 +679,6 @@ public class Option implements Cloneable, Serializable {
         return since;
     }
 
-
     /**
      * Gets the type of this Option.
      *
@@ -691,9 +701,7 @@ public class Option implements Cloneable, Serializable {
      * Gets the specified value of this Option or {@code null} if there is no value.
      *
      * @param index The index of the value to be returned.
-     *
      * @return the specified value of this Option or {@code null} if there is no value.
-     *
      * @throws IndexOutOfBoundsException if index is less than 1 or greater than the number of the values for this Option.
      */
     public String getValue(final int index) throws IndexOutOfBoundsException {
@@ -704,7 +712,6 @@ public class Option implements Cloneable, Serializable {
      * Gets the value/first value of this Option or the {@code defaultValue} if there is no value.
      *
      * @param defaultValue The value to be returned if there is no value.
-     *
      * @return the value/first value of this Option or the {@code defaultValue} if there are no values.
      */
     public String getValue(final String defaultValue) {
@@ -713,9 +720,9 @@ public class Option implements Cloneable, Serializable {
     }
 
     /**
-     * Gets the values of this Option as a String array or null if there are no values.
+     * Gets the values of this Option as a String array or an empty array if there are no values.
      *
-     * @return the values of this Option as a String array or null if there are no values.
+     * @return the values of this Option as a String array or an empty array if there are no values.
      */
     public String[] getValues() {
         return hasNoValues() ? null : values.toArray(EMPTY_STRING_ARRAY);
@@ -731,9 +738,9 @@ public class Option implements Cloneable, Serializable {
     }
 
     /**
-     * Gets the values of this Option as a List or null if there are no values.
+     * Gets the values of this Option as a List.  Will return an empty list if there are no values.
      *
-     * @return the values of this Option as a List or null if there are no values.
+     * @return the values of this Option as a List or an empty List if there are no values.
      */
     public List<String> getValuesList() {
         return values;
@@ -835,9 +842,9 @@ public class Option implements Cloneable, Serializable {
      */
     void processValue(final String value) {
         if (argCount == UNINITIALIZED) {
-            throw new IllegalArgumentException("NO_ARGS_ALLOWED");
+            throw new IllegalStateException("NO_ARGS_ALLOWED");
         }
-        String add = value;
+        String add = Objects.requireNonNull(value, "value");
         // this Option has a separator character
         if (hasValueSeparator()) {
             // get the separator character
@@ -955,7 +962,7 @@ public class Option implements Cloneable, Serializable {
     /**
      * Sets the type of this Option.
      * <p>
-     * <b>Note:</b> this method is kept for binary compatibility and the input type is supposed to be a {@link Class} object.
+     * <strong>Note:</strong> this method is kept for binary compatibility and the input type is supposed to be a {@link Class} object.
      * </p>
      *
      * @param type the type of this Option.
